@@ -1,4 +1,4 @@
-from models import Colors, Coordinate, Powerup, Controls
+from . import Colors, Coordinate, Powerup, Controls
 
 
 class Bot:
