@@ -1,4 +1,4 @@
-from models import Coordinate, Direction
+from . import Coordinate, Direction
 
 
 class Bullet:
