@@ -1,4 +1,4 @@
-from models import Tile
+from . import Tile
 
 
 class Map:
