@@ -1,4 +1,4 @@
-from models import Coordinate
+from . import Coordinate
 
 
 class Pod:
