@@ -20,4 +20,4 @@ class State:
     @classmethod
     def fromState(self, state):
         return self(state.bots, state.bullets, state.powerups, state.pods, state.startedOn, state.mapId, state.lastTick,
-                    state.lastTickDuration, state.paused, state.map)
+                    state.lastTickDuration, state.paused, None)
